<?php
// Register license page in admin menu
add_action('admin_menu', 'eventer_register_license_page');
function eventer_register_license_page() {
    add_submenu_page(
        'edit.php?post_type=eventer',
        __('License', 'eventer'),
        __('License', 'eventer'),
        'manage_options',
        'eventer-license',
        'eventer_license_callback'
    );
}

// Disallow access to certain admin pages if not authenticated
add_action('admin_init', 'disallowed_eventer_admin_pages');
function disallowed_eventer_admin_pages() {
  global $pagenow;

  if ($pagenow == 'edit.php' || $pagenow == 'admin.php') {
    $domain = preg_replace('|https?://([^/]+)|', '$1', home_url());
    $localhost = false;

    // Check for common local development environments
    $local_patterns = [
      'localhost',
      '127.0.0.1',
      '.local',
      '.test',
      '.dev',
      '.mamp',
      '.localwp'
    ];

    foreach ($local_patterns as $pattern) {
      if (strpos($domain, $pattern) !== false || preg_match('|^[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+$|', $domain)) {
        $localhost = true;
        break;
      }
    }

    if (!$localhost && (!empty($_REQUEST['page']) && ($_REQUEST['page'] == 'eventer_settings_options' || $_REQUEST['page'] == 'eventer_bookings'))) {
      $purchase_code = get_eventer_purchase_code(); // Function defined below
      if (empty($purchase_code)) {
        wp_safe_redirect(admin_url('edit.php?post_type=eventer&page=eventer-license'));
        exit;
      }
    }
  }
}

// Function to retrieve purchase code based on multisite
function get_eventer_purchase_code() {
  // Check for multisite and use blog-specific option
  if (is_multisite()) {
    $blog_id = get_current_blog_id();
    return get_option('eventer_auth_code_' . $blog_id);
  } else {
    // Single site, use existing option
    return get_option('eventer_authenticate');
  }
}

// Process authentication via AJAX
add_action('wp_ajax_eventerProcessAuthentication', 'eventerProcessAuthentication');
function eventerProcessAuthentication() {
  $status = $_REQUEST['status'];
  $authCode = $_REQUEST['authCode'];

  // Use blog-specific option for multisite
  if (is_multisite()) {
    $blog_id = get_current_blog_id();
    update_option('eventer_authenticate_' . $blog_id, $status);
    update_option('eventer_auth_code_' . $blog_id, $authCode);
  } else {
    update_option('eventer_authenticate', $status);
    update_option('eventer_auth_code', $authCode);
  }

  wp_die();
}

// Display callback for the license activation page
function eventer_license_callback() {
  ?>
  <div class="wrap about-wrap">
    <h1><?php esc_html_e('License Activation', 'eventer'); ?></h1>
    <?php
    $purchaseCode = $purchaseCodeRaw = $showRegisterForm = "";
    $showUnRegisterForm = ' style="display: none;"';

    $purchase_code = get_eventer_purchase_code(); // Use the function to retrieve code
    if (!empty($purchase_code)) {
      $purchaseCode = "xxxxxx-xxxx-xxxxxxx-xxxxx" . substr($purchase_code, -4);
      $purchaseCodeRaw = $purchase_code;
      $showRegisterForm = ' style="display: none;"';
      $showUnRegisterForm = "";
    }
    ?>
    <div class="imi-box-content activation_welcome_box" <?php echo $showRegisterForm; ?>>
      <p>
        <?php echo esc_html__('Thank you for choosing Eventer! Please register it to get access to all the features & settings. The instructions below must be followed exactly to successfully register your purchase.', 'eventer'); ?>
      </p>
      <div class="eventer-activate"></div>
    </div>
    <div class="eventer-validation-steps">
      <div class="imi-box-content imi-theme-reg-box" <?php echo $showUnRegisterForm; ?>>
        <h3 style="color: green; text-align: left"><?php esc_html_e('Plugin is active', 'eventer'); ?></h3>
      </div>
      <div class="imi-box-content imi-theme-reg-box" <?php echo $showRegisterForm; ?>>
        <h3 style="color: red; text-align: left"><?php esc_html_e('Please activate your Eventer purchase code', 'eventer'); ?></h3>
      </div>
      <div class="imi-box-content">
        <form class="imi_eventer_val" <?php echo $showRegisterForm; ?>>
          <label for="imi_purchase_code"><?php esc_html_e('Purchase Code:', 'framework') ?></label>
          <input type="text" value="" class="eventer-purchase-code">
          <input type="hidden" value="<?php echo urlencode(site_url()); ?>" class="eventer-verified-dm">
          <input type="hidden" value="<?php echo esc_url($_SERVER['REMOTE_ADDR']); ?>" class="eventer-server-type">
          <button type="submit" class="imi-submit-btn">Register</button>
          <div class="eventer-message"></div>
        </form>
        <form class="imi_eventer_vals" <?php echo $showUnRegisterForm; ?>>
          <label for="imi_purchase_code"><?php esc_html_e('Purchase Code:', 'framework') ?></label>
          <input type="text" class="eventer-hidden-code" value="<?php echo esc_attr($purchaseCode); ?>">
          <input type="hidden" value="<?php echo urlencode(site_url()) ?>" class="eventer-verified-dm">
          <input type="hidden" value="<?php echo esc_url($_SERVER['REMOTE_ADDR']); ?>" class="eventer-server-type">
          <input type="hidden" value="<?php echo esc_attr($purchaseCodeRaw); ?>" class="eventer-purchase-code">
          <button type="submit" class="imi-submit-btn">Unregister</button>
          <p><small><?php esc_html_e('Unregister the purchase code to use it on any other domain/website.', 'eventer'); ?></small></p>
          <div class="eventer-message"></div>
        </form>
        <div <?php echo $showRegisterForm; ?>>
          <h3><?php esc_html_e('Instructions for registering your purchase code', 'framework'); ?></h3>
          <p><?php esc_html_e('Whenever you purchase an item via Codecanyon, they will provide you with a purchase code for each item purchased. The purchase code is used for purchase validation for use of the item and also so that you can access the support.', 'eventer'); ?></p>
          <ol>
            <li><?php esc_html_e('Log in to Codecanyon with your Envato account.', 'eventer'); ?></li>
            <li><?php esc_html_e('Navigate to the Downloads tab. Your all purchases and items appear in this page.', 'eventer'); ?></li>
            <li><?php esc_html_e('Locate your item, and click the Download button.', 'eventer'); ?></li>
            <li><?php esc_html_e('Choose between License Certificate & Purchase Code (PDF) or License Certificate & Purchase Code (Text).', 'eventer'); ?></li>
            <li><?php esc_html_e('Open the file to find the purchase code.', 'eventer'); ?></li>
          </ol>
          <p><a href="https://www.youtube.com/watch?v=yTScONNFnZ8" target="_blank"><?php esc_html_e('See instructions video', 'eventer'); ?></a></p>
        </div>
      </div>
    </div>
  </div>
  <?php
}
?>