<?php
/* PDF TICKETS DOWNLOAD
=================================================== */

// Register custom endpoint for PDF download
add_action('init', 'register_pdf_download_endpoint');
function register_pdf_download_endpoint() {
    add_rewrite_rule('download-pdf-tickets/([0-9]+)/?', 'index.php?download_pdf_tickets=$matches[1]', 'top');
    flush_rewrite_rules(); // Flush rewrite rules
}

// Add custom query variable for PDF download
add_filter('query_vars', 'add_pdf_download_query_var');
function add_pdf_download_query_var($vars) {
    $vars[] = 'download_pdf_tickets';
    return $vars;
}

// Handle PDF download request
add_action('template_redirect', 'handle_pdf_download_request');
function handle_pdf_download_request() {
    $booking_id = get_query_var('download_pdf_tickets');
    if ($booking_id) {
        // Generate the zip file and initiate the download
        download_pdf_tickets_as_zip($booking_id);
        exit;
    }
}

// Function to generate and download PDF tickets as a zip file
function download_pdf_tickets_as_zip($booking_id) {
    // Start output buffering to handle errors
    ob_start();

    // Define the directory where PDF tickets are stored
    $upload_dir = wp_upload_dir();
    $pdf_dir = $upload_dir['basedir'] . '/eventer';

    // Fetch all PDFs in the directory
    $pattern = "$pdf_dir/{$booking_id}-*.pdf";
    $all_files = glob($pattern);

    // Log all files found for the booking ID
    error_log("All files found for booking ID $booking_id: " . print_r($all_files, true));

    if (empty($all_files)) {
        $error_message = __('No PDF tickets found for this booking. Click on the "Create Tickets" button first to create/re-create tickets PDF file.', 'eventer');
        set_transient('eventer_pdf_error', $error_message, 30);
        wp_redirect($_SERVER['HTTP_REFERER']);
        exit;
    }

    // Sort files by creation date, extracted from the filename
    usort($all_files, function($a, $b) {
        $time_a = filemtime($a);
        $time_b = filemtime($b);
        return $time_b - $time_a; // Sort descending (latest first)
    });

    // Get the latest file(s) only
    $latest_files = [];
    $latest_timestamp = filemtime($all_files[0]);

    foreach ($all_files as $file) {
        if (filemtime($file) == $latest_timestamp) {
            $latest_files[] = $file;
        } else {
            break;
        }
    }

    // Create a new zip file
    $zip = new ZipArchive();
    $zip_filename = "$pdf_dir/tickets_$booking_id.zip";

    if ($zip->open($zip_filename, ZipArchive::CREATE) !== TRUE) {
        $error_message = __('Failed to create zip file.', 'eventer');
        set_transient('eventer_pdf_error', $error_message, 30);
        wp_redirect($_SERVER['HTTP_REFERER']);
        exit;
    }

    // Add the latest files to the zip archive
    foreach ($latest_files as $file) {
        $zip->addFile($file, basename($file));
    }

    $zip->close();

    // Download the zip file
    header('Content-Type: application/zip');
    header('Content-Disposition: attachment; filename=' . basename($zip_filename));
    header('Content-Length: ' . filesize($zip_filename));
    readfile($zip_filename);

    // Delete the zip file after download
    unlink($zip_filename);
    exit;
}


// Display admin notice for PDF errors
add_action('admin_notices', 'eventer_pdf_error_notice');
function eventer_pdf_error_notice() {
    if ($error_message = get_transient('eventer_pdf_error')) {
        delete_transient('eventer_pdf_error');
        ?>
        <div class="notice notice-error">
            <p><?php echo $error_message; ?></p>
        </div>
        <?php
    }
}

// Function to get the PDF download URL
function get_pdf_download_url($booking_id) {
    return site_url("/download-pdf-tickets/$booking_id");
}
?>